Core Notions
############

In this section, you'll learn what are the core notions in the service and where they are. You should read this first if you plan to write a plugin.

.. autoclass:: controller.models.Controller
   :members:

.. automodule:: device.models
    :members:

